@@ -95,7 +95,7 @@ class Node:
     def _bash_template(command: str) -> str:
         return f"""#!/bin/bash
 echo Creating Virtual Environment
-virtualenv .task_venv
+virtualenv .task_venv --system-site-packages
 echo Activate Environment
 source .task_venv/bin/activate
 echo Run Main Command
