@@ -9,11 +9,27 @@ class Task(TaskBase):
 
     def __init__(self, *args, **kwargs):
         self.run_was_called = False
-        self.record_provenance_was_called = False
+        self.pre_run_was_called = False
+        self.post_run_was_called = False
         super().__init__(*args, **kwargs)
 
     def run(self):
         self.run_was_called = True
 
-    def record_provenance(self):
-        self.record_provenance_was_called = True
+    def pre_run(self) -> None:
+        self.pre_run_was_called = True
+
+    def post_run(self) -> None:
+        self.post_run_was_called = True
+
+
+class Task2(Task):
+    pass
+
+
+class Task3(Task):
+    pass
+
+
+class Task4(Task):
+    pass
